@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(generate_table);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-03'; # DATE
 our $DIST = 'Text-Table-Any'; # DIST
-our $VERSION = '0.112'; # VERSION
+our $VERSION = '0.113'; # VERSION
 
 our %BACKEND_FEATURES = (
     "Term::Table" => {
@@ -89,7 +89,7 @@ our %BACKEND_FEATURES = (
         backend_opts => 1,
         backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
         align => 0,
-        align_note => "TODO, backend does not support yet, parameter alreaday passed",
+        align_note => "TODO, backend does not support yet, parameter already passed",
     },
     "Text::Table::HTML::DataTables" => {
         rows => 1,
@@ -99,7 +99,7 @@ our %BACKEND_FEATURES = (
         backend_opts => 1,
         backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
         align => 0,
-        align_note => "TODO, backend does not support yet, parameter alreaday passed",
+        align_note => "TODO, backend does not support yet, parameter already passed",
     },
     "Text::Table::LTSV" => {
         rows => 1,
@@ -152,6 +152,7 @@ our %BACKEND_FEATURES = (
         backend_opts => 1,
         backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
         align => 0,
+        align_note => "",
     },
     "Text::Table::TickitWidget" => {
         rows => 1,
@@ -179,7 +180,7 @@ our %BACKEND_FEATURES = (
         backend_opts => 1,
         backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
         align => 0,
-        align_note => "TODO, backend does not support yet, parameter alreaday passed",
+        align_note => "TODO, backend does not support yet, parameter already passed",
     },
     "Text::Table::TinyColor" => {
         rows => 1,
@@ -189,7 +190,7 @@ our %BACKEND_FEATURES = (
         backend_opts => 1,
         backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
         align => 0,
-        align_note => "TODO, backend does not support yet, parameter alreaday passed",
+        align_note => "TODO, backend does not support yet, parameter already passed",
     },
     "Text::Table::TinyColorWide" => {
         rows => 1,
@@ -199,7 +200,7 @@ our %BACKEND_FEATURES = (
         backend_opts => 1,
         backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
         align => 0,
-        align_note => "TODO, backend does not support yet, parameter alreaday passed",
+        align_note => "TODO, backend does not support yet, parameter already passed",
     },
     "Text::Table::TinyWide" => {
         rows => 1,
@@ -209,7 +210,7 @@ our %BACKEND_FEATURES = (
         backend_opts => 1,
         backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
         align => 0,
-        align_note => "TODO, backend does not support yet, parameter alreaday passed",
+        align_note => "TODO, backend does not support yet, parameter already passed",
     },
     "Text::Table::TSV" => {
         rows => 1,
@@ -616,7 +617,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.112 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2022-05-03.
+This document describes version 0.113 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2022-05-03.
 
 =head1 SYNOPSIS
 
@@ -850,37 +851,37 @@ backends:
 
 Support matrix for each backend:
 
- +-------------------------------+-------+--------------+------------------------------------------------------------------------------------------------+---------+------------+------+---------------+
- | backend                       | align | backend_opts | backend_opts_note                                                                              | caption | header_row | rows | separate_rows |
- +-------------------------------+-------+--------------+------------------------------------------------------------------------------------------------+---------+------------+------+---------------+
- | Term::Table                   | 0     |              |                                                                                                | 0       | 1          | 1    | 0             |
- | Term::TablePrint              | 0     |              |                                                                                                | 0       | 1          | 1    | 0             |
- | Text::ANSITable               | 1     |              |                                                                                                | 0       | 1          | 1    | 1             |
- | Text::ASCIITable              | 1     |              |                                                                                                | 0       | 1          | 1    | 0             |
- | Text::FormatTable             | 1     |              |                                                                                                | 0       | 0          | 1    | 0             |
- | Text::MarkdownTable           | 0     |              |                                                                                                | 0       | 1          | 1    | 0             |
- | Text::Table                   | 1     |              |                                                                                                | 0       | 0          | 1    | 0             |
- | Text::Table::ASV              | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
- | Text::Table::CSV              | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
- | Text::Table::HTML             | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1       | 1          | 1    | 0             |
- | Text::Table::HTML::DataTables | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1       | 1          | 1    | 0             |
- | Text::Table::LTSV             | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 0          | 1    | 0             |
- | Text::Table::Manifold         | 1     |              |                                                                                                | 0       | 1          | 1    | 0             |
- | Text::Table::More             | 1     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::Org              | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::Paragraph        | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
- | Text::Table::Sprintf          | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::TSV              | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 0          | 1    | 0             |
- | Text::Table::TickitWidget     | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
- | Text::Table::Tiny             | 1     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::TinyBorderStyle  | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::TinyColor        | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::TinyColorWide    | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::TinyWide         | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
- | Text::Table::XLSX             | 0     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
- | Text::TabularDisplay          | 0     |              |                                                                                                | 0       | 0          | 1    | 0             |
- | Text::UnicodeBox::Table       | 0     |              |                                                                                                | 0       | 1          | 1    | 0             |
- +-------------------------------+-------+--------------+------------------------------------------------------------------------------------------------+---------+------------+------+---------------+
+ +-------------------------------+-------+--------------------------------------------------------------+--------------+------------------------------------------------------------------------------------------------+---------+------------+------+---------------+
+ | backend                       | align | align_note                                                   | backend_opts | backend_opts_note                                                                              | caption | header_row | rows | separate_rows |
+ +-------------------------------+-------+--------------------------------------------------------------+--------------+------------------------------------------------------------------------------------------------+---------+------------+------+---------------+
+ | Term::Table                   | 0     |                                                              |              |                                                                                                | 0       | 1          | 1    | 0             |
+ | Term::TablePrint              | 0     |                                                              |              |                                                                                                | 0       | 1          | 1    | 0             |
+ | Text::ANSITable               | 1     |                                                              |              |                                                                                                | 0       | 1          | 1    | 1             |
+ | Text::ASCIITable              | 1     |                                                              |              |                                                                                                | 0       | 1          | 1    | 0             |
+ | Text::FormatTable             | 1     | c(enter) alignment is not supported, will fallback to l(eft) |              |                                                                                                | 0       | 0          | 1    | 0             |
+ | Text::MarkdownTable           | 0     |                                                              |              |                                                                                                | 0       | 1          | 1    | 0             |
+ | Text::Table                   | 1     |                                                              |              |                                                                                                | 0       | 0          | 1    | 0             |
+ | Text::Table::ASV              | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
+ | Text::Table::CSV              | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
+ | Text::Table::HTML             | 0     | TODO, backend does not support yet, parameter already passed | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1       | 1          | 1    | 0             |
+ | Text::Table::HTML::DataTables | 0     | TODO, backend does not support yet, parameter already passed | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1       | 1          | 1    | 0             |
+ | Text::Table::LTSV             | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 0          | 1    | 0             |
+ | Text::Table::Manifold         | 1     |                                                              |              |                                                                                                | 0       | 1          | 1    | 0             |
+ | Text::Table::More             | 1     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::Org              | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::Paragraph        | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
+ | Text::Table::Sprintf          | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::TSV              | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 0          | 1    | 0             |
+ | Text::Table::TickitWidget     | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
+ | Text::Table::Tiny             | 1     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::TinyBorderStyle  | 0     | TODO, backend does not support yet, parameter already passed | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::TinyColor        | 0     | TODO, backend does not support yet, parameter already passed | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::TinyColorWide    | 0     | TODO, backend does not support yet, parameter already passed | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::TinyWide         | 0     | TODO, backend does not support yet, parameter already passed | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 1             |
+ | Text::Table::XLSX             | 0     |                                                              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0       | 1          | 1    | 0             |
+ | Text::TabularDisplay          | 0     |                                                              |              |                                                                                                | 0       | 0          | 1    | 0             |
+ | Text::UnicodeBox::Table       | 0     | TODO: backend supports left/right                            |              |                                                                                                | 0       | 1          | 1    | 0             |
+ +-------------------------------+-------+--------------------------------------------------------------+--------------+------------------------------------------------------------------------------------------------+---------+------------+------+---------------+
 
 =item * rows
 
